@@ -7,11 +7,14 @@ from .entity import (
     ClusterConfig,
     ClusterConfigData,
     Condition,
+    DNSInventory,
     DatapipeDataInfo,
     DatapipeServerInfo,
     FileTemplateVariables,
     FilesTemplateVariables,
+    NodeInventory,
     RandomTemplateVariables,
+    RecoverSetting,
     TaskDeleteRequest,
     TaskDetail,
     TaskItem,
@@ -24,17 +27,21 @@ from .dto import (
     ClusterConfigDTO,
     ClusterConfigDataDTO,
     ConditionDTO,
+    DNSInventoryDTO,
     DatapipeDataInfoDTO,
     DatapipeServerInfoDTO,
     FileTemplateVariablesDTO,
     FilesTemplateVariablesDTO,
+    NodeInventoryDTO,
     RandomTemplateVariablesDTO,
+    RecoverSettingDTO,
     TaskDeleteRequestDTO,
     TaskDetailDTO,
     TaskItemDTO,
     TaskRequestDTO
 )
 from .value_obj import (
+    K3SNodeType,
     Status,
     UDate,
     UDict,
@@ -370,3 +377,54 @@ class TaskItemAssembler(Assembler):
             exception = None if x.exception is None else x.exception.get_value()
         )
 task_item_assembler=TaskItemAssembler()
+
+
+
+class NodeInventoryAssembler(Assembler):
+    def to_entity(self, dto: NodeInventoryDTO):
+        return NodeInventory(
+            node_type = UStr(dto.node_type),
+            amount = UInt(dto.amount)
+        )
+    def to_dto(self, x:NodeInventory):
+        return NodeInventoryDTO(
+            node_type = x.node_type.get_value(),
+            amount = x.amount.get_value()
+        )
+node_inventory_assembler=NodeInventoryAssembler()
+
+
+
+class DNSInventoryAssembler(Assembler):
+    def to_entity(self, dto: DNSInventoryDTO):
+        return DNSInventory(
+            domain = UStr(dto.domain),
+            subdomain = UStr(dto.subdomain),
+            node_type = None if dto.node_type is None else K3SNodeType(dto.node_type),
+            pod_name = None if dto.pod_name is None else UStr(dto.pod_name),
+            namespace_name = None if dto.namespace_name is None else UStr(dto.namespace_name)
+        )
+    def to_dto(self, x:DNSInventory):
+        return DNSInventoryDTO(
+            domain = x.domain.get_value(),
+            subdomain = x.subdomain.get_value(),
+            node_type = None if x.node_type is None else x.node_type.get_value(),
+            pod_name = None if x.pod_name is None else x.pod_name.get_value(),
+            namespace_name = None if x.namespace_name is None else x.namespace_name.get_value()
+        )
+dns_inventory_assembler=DNSInventoryAssembler()
+
+
+
+class RecoverSettingAssembler(Assembler):
+    def to_entity(self, dto: RecoverSettingDTO):
+        return RecoverSetting(
+            node_inventory = None if dto.node_inventory is None else [node_inventory_assembler.to_entity(m) for m in dto.node_inventory],
+            dns_inventory = None if dto.dns_inventory is None else [dns_inventory_assembler.to_entity(m) for m in dto.dns_inventory]
+        )
+    def to_dto(self, x:RecoverSetting):
+        return RecoverSettingDTO(
+            node_inventory = None if x.node_inventory is None else [node_inventory_assembler.to_dto(m) for m in x.node_inventory],
+            dns_inventory = None if x.dns_inventory is None else [dns_inventory_assembler.to_dto(m) for m in x.dns_inventory]
+        )
+recover_setting_assembler=RecoverSettingAssembler()
