@@ -7,11 +7,14 @@ from .entity import (
     ClusterConfig,
     ClusterConfigData,
     Condition,
+    DNSInventory,
     DatapipeDataInfo,
     DatapipeServerInfo,
     FileTemplateVariables,
     FilesTemplateVariables,
+    NodeInventory,
     RandomTemplateVariables,
+    RecoverSetting,
     TaskDeleteRequest,
     TaskDetail,
     TaskItem,
@@ -24,17 +27,21 @@ from .do import (
     ClusterConfigDO,
     ClusterConfigDataDO,
     ConditionDO,
+    DNSInventoryDO,
     DatapipeDataInfoDO,
     DatapipeServerInfoDO,
     FileTemplateVariablesDO,
     FilesTemplateVariablesDO,
+    NodeInventoryDO,
     RandomTemplateVariablesDO,
+    RecoverSettingDO,
     TaskDeleteRequestDO,
     TaskDetailDO,
     TaskItemDO,
     TaskRequestDO
 )
 from .value_obj import (
+    K3SNodeType,
     Status,
     UDate,
     UDict,
@@ -370,3 +377,54 @@ class TaskItemConverter(Converter):
             exception = None if x.exception is None else x.exception.get_value()
         )
 task_item_converter=TaskItemConverter()
+
+
+
+class NodeInventoryConverter(Converter):
+    def to_entity(self, do: NodeInventoryDO):
+        return NodeInventory(
+            node_type = UStr(do.node_type),
+            amount = UInt(do.amount)
+        )
+    def to_do(self, x:NodeInventory):
+        return NodeInventoryDO(
+            node_type = x.node_type.get_value(),
+            amount = x.amount.get_value()
+        )
+node_inventory_converter=NodeInventoryConverter()
+
+
+
+class DNSInventoryConverter(Converter):
+    def to_entity(self, do: DNSInventoryDO):
+        return DNSInventory(
+            domain = UStr(do.domain),
+            subdomain = UStr(do.subdomain),
+            node_type = None if do.node_type is None else K3SNodeType(do.node_type),
+            pod_name = None if do.pod_name is None else UStr(do.pod_name),
+            namespace_name = None if do.namespace_name is None else UStr(do.namespace_name)
+        )
+    def to_do(self, x:DNSInventory):
+        return DNSInventoryDO(
+            domain = x.domain.get_value(),
+            subdomain = x.subdomain.get_value(),
+            node_type = None if x.node_type is None else x.node_type.get_value(),
+            pod_name = None if x.pod_name is None else x.pod_name.get_value(),
+            namespace_name = None if x.namespace_name is None else x.namespace_name.get_value()
+        )
+dns_inventory_converter=DNSInventoryConverter()
+
+
+
+class RecoverSettingConverter(Converter):
+    def to_entity(self, do: RecoverSettingDO):
+        return RecoverSetting(
+            node_inventory = None if do.node_inventory is None else [node_inventory_converter.to_entity(m) for m in do.node_inventory],
+            dns_inventory = None if do.dns_inventory is None else [dns_inventory_converter.to_entity(m) for m in do.dns_inventory]
+        )
+    def to_do(self, x:RecoverSetting):
+        return RecoverSettingDO(
+            node_inventory = None if x.node_inventory is None else [node_inventory_converter.to_do(m) for m in x.node_inventory],
+            dns_inventory = None if x.dns_inventory is None else [dns_inventory_converter.to_do(m) for m in x.dns_inventory]
+        )
+recover_setting_converter=RecoverSettingConverter()
