@@ -142,4 +142,25 @@ class TaskItemDO(BaseModel):
     details: Optional[List[TaskDetailDO]]
     entry_time: Optional[datetime.datetime]
     exit_time: Optional[datetime.datetime]
-    exception: Optional[str]
\ No newline at end of file
+    exception: Optional[str]
+
+
+
+class NodeInventoryDO(BaseModel):
+    node_type: str
+    amount: int
+
+
+
+class DNSInventoryDO(BaseModel):
+    domain: str
+    subdomain: str
+    node_type: Optional[str]
+    pod_name: Optional[str]
+    namespace_name: Optional[str]
+
+
+
+class RecoverSettingDO(BaseModel):
+    node_inventory: Optional[List[NodeInventoryDO]]
+    dns_inventory: Optional[List[DNSInventoryDO]]
\ No newline at end of file
