@@ -7,7 +7,7 @@ def __fill_class(model_json, model_class):
     fields = model_class.__fields__
     new_json = {}
     for key in model_json:
-        if key in fields and issubclass(fields[key].type_, BaseModel):
+        if key in fields and issubclass(fields[key].type_, BaseModel) and model_json[key] is not None:
             new_json[key] = __fill_class(model_json[key], fields[key].type_)
         elif key in fields:
             new_json[key] = model_json[key]
